.. _grpc-kvstore-driver:

``grpc`` Key-Value Store driver
===============================

The ``grpc`` driver connects to a gRPC server which implements
tensorstore_grpc.kvstore.KvStoreService.

.. json:schema:: kvstore/grpc

Limitations
-----------

.. note::
   This is an experimental driver.